Processor.App.Extractor.extractor
=================================

.. automodule:: Processor.App.Extractor.extractor

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      BaseExtractor
   
   

   
   
   



